Learn R Programming

incubate (version 1.3.0)

coef.incubate_fit: Coefficients of a delay-model fit.

Description

Coefficients of a delay-model fit.

Usage

# S3 method for incubate_fit
coef(object, transformed = FALSE, group = NULL, ...)

Value

named coefficient vector

Arguments

object

object that is a incubate_fit

transformed

flag. Do we request the transformed parameters as used within the optimization?

group

character string to request the canonical parameter for one group

...

further arguments, currently not used.