Bias-corrected bootstrap confidence limits (either quantile-based or normal-approximation based) are generated. Optionally, there are also variants that use a log-transformation first. At least R=1000 bootstrap replications are recommended. Default are quantile-based confidence intervals that internally use a log-transformation.
# S3 method for incubate_fit
confint(
object,
parm,
level = 0.95,
R = 199L,
bs_data,
bs_infer = c("logquantile", "lognormal", "quantile", "quantile0", "normal", "normal0"),
useBoot = FALSE,
...
)A matrix (or vector) with columns giving lower and upper confidence limits for each parameter.
object of class incubate_fit
character. Which parameters to get confidence interval for?
numeric. Which is the requested confidence level for the interval? Default value is 0.95
number of bootstrap replications. Used only if not bs_data-object is provided.
character or bootstrap data object. If character, it specifies which type of bootstrap is requested and the bootstrap data will be generated. Data can also be provided here directly. If missing it uses parametric bootstrap.
character. Which type of bootstrap inference is requested to generate the confidence interval?
logical. Delegate bootstrap confint calculation to the boot-package?
further arguments, currently not used.