The objective function carries the given data in its environment and it is to be minimized.
R's standard routine stats::optim does the numerical optimization, using numerical derivatives.
or the analytical solution is returned directly if available.
delay_fit(objFun, optim_args = NULL, verbose = 0)optimization object including a named parameter vector or NULL in case of errors during optimization
objective function to be minimized
list of own arguments for optimization. If NULL it uses the default optim arguments associated to the objective function.
integer that indicates the level of verboseness. Default 0 is quiet.