Learn R Programming

incubate (version 1.4.0)

plot.incubate_fit: Plot a fitted delay-model object of class incubate_fit

Description

The fitted delay-model is plotted: a Kaplan-Meier survival curve is shown together with the parametric model fit. Optionally, a fit of a second delay-model can be added. When given, we do some preliminary checks that the two models do match together.

Usage

# S3 method for incubate_fit
plot(x, y, title, subtitle, xlim, ...)

Arguments

x

a fitted delay-model

y

an optional second fitted delay-model

title

character. Optionally, provide a title to the plot.

subtitle

character. Optionally, provide a subtitle to the plot. By default the coefficients are shown.

xlim

numeric. Optionally, limits for the x-axis (time). If unspecified starts from 0 to last observation.

...

further arguments. Not in use here (it is required for generic plot function)

Details

This function requires the ggplot2-package to be installed.