Learn R Programming

incubate (version 1.3.0)

stankovic: Survival of mice with glioma under different treatments

Description

This data set stems from an animal experiment described in Stankovic (2018). In particular, the data in question is shown in Figure 6J and 6K.

Usage

stankovic

Arguments

Format

Figure

The figure in the publication where the data is shown

Time

Survival in days

Status

Right-censor status: 1 means observed event

Group

Experimental group identifier

Colour

Colour used in the Stankovic publication to mark this group

Details

The data were read directly from the survival plots in the publication with the help of Plot Digitizer, version 2.6.9.