Learn R Programming

incubate (version 1.4.0)

test_GOF: Goodness-of-fit (GOF) test statistic (experimental!)

Description

The GOF-test is performed for a fitted delay-model that was fit using MPSE. There are different GOF-tests implemented:

  • Moran GOF is based on spacings, like the MPSE-criterion itself.

  • Pearson GOF uses categories and compares observed to expected frequencies.

Usage

test_GOF(
  delayFit,
  method = c("moran", "pearson", "nikulin", "NRR"),
  estimated = TRUE,
  verbose = 0
)

Value

An htest-object containing the GOF-test result

Arguments

delayFit

delay_model fit object

method

character(1). which method to use for GOF. Default is 'moran'.

estimated

flag. Moran test: was the parameter estimated?

verbose

integer. Verbosity level. The higher the more verbose debugging output.

Details

Note that the GOF-tests are currently only implemented for models fitted with maximum product of spacings estimation (MPSE). These tests (Moran & Pearson) are still experimental. So, use with caution. Experimental code!