Learn R Programming

incubate (version 1.4.0)

transform.incubate_fit: Transform observed data to unit interval

Description

The transformation used is the probability integral transform: the cumulative distribution function with the estimated parameters of the model fit takes the data into the 0-1 interval. All available data in the model fit is transformed. Censored observations lead to censored back-transformed observations as well.

Usage

# S3 method for incubate_fit
transform(`_data`, ...)

Value

The transformed data, either a vector (for single group) or a list with entries x and y (in two group scenario)

Arguments

_data

a fitted model object of class incubate_fit

...

currently ignored