incubate_fit-object with specified optimization argumentsThis function is useful when only an optimization argument is to be changed.
If more things need to be changed go back to delay_model and start from scratch.
# S3 method for incubate_fit
update(object, optim_args = NULL, verbose = 0, ...)The updated fitted object of class incubate_fit or NULL in case of failure.
incubate_fit-object
optimization arguments
integer flag. Requested verbosity during delay_fit
further arguments, currently not used.