Learn R Programming

incubate (version 1.4.0)

w1Fint: Internal MLEw-weight W1 function according to sampling distribution Weight W1 for given sample sizes (of one group). For small nObs we use direct results from Monte-Carlo simulation. For higher nObs we use an approximation (based on Wilson-Hilferty transformation).

Description

Note that in R there is the numeric routine stats::qgamma which could also be used as in stats::qgamma(p=.5, shape = 10, rate = 10) for n=10.

Usage

w1Fint(nObs)

Value

numeric. W1-value corrsponding to nObs. Same length as nObs

Arguments

nObs

numeric. number of observations (vectorized)