Learn R Programming

incubate (version 1.4.0)

w2Fint: Internal MLEw weight function W2 according to sampling distribution W2 is either taken directly from the MCSS-results (if available) or are taken from the smooth approximation function, otherwise.

Description

Internal MLEw weight function W2 according to sampling distribution W2 is either taken directly from the MCSS-results (if available) or are taken from the smooth approximation function, otherwise.

Usage

w2Fint(nObs)

Value

W2 (same size as nObs)

Arguments

nObs

numeric. Sample size (vectorized) of one group