The primary optimization routine is BFGS from stats::optim.
If this fails for some reason we try an alternative which is implemented here.
It can use the derivative-free minimizaiton through bobyqa or the PORT-routine nlminb.
minObjFunAlt(
objFun,
start,
lower = -Inf,
upper = +Inf,
verbose = 0,
method = c("bobyqa", "nlminb")
)optimization object with some common entries like parOpt, valOpt
convergence, methodOpt and counts. Or NULL in case of failure.
function to minimize
vector of start values for parameters
numeric. lower bound for parameters (boxed constraint)
numeric. upper bound for parameters (boxed constraint)
numeric. Verbosity level
Specifies which optimizer to use
This is only a thin wrapper to the chosen alternative optimizer.