incubate_fitThe fitted delay-model is plotted: a Kaplan-Meier survival curve is shown together with the parametric model fit. Optionally, a fit of a second delay-model can be added. When given, we do some preliminary checks that the two models do match together.
# S3 method for incubate_fit
plot(x, y, title, subtitle, xlim, ...)a fitted delay-model
an optional second fitted delay-model
character. Optionally, provide a title to the plot.
character. Optionally, provide a subtitle to the plot. By default the coefficients are shown.
numeric. Optionally, limits for the x-axis (time). If unspecified starts from 0 to last observation.
further arguments. Not in use here (it is required for generic plot function)
This function requires the ggplot2-package to be installed.