The GOF-test is performed for a fitted delay-model that was fit using MPSE. There are different GOF-tests implemented:
Moran GOF is based on spacings, like the MPSE-criterion itself.
Pearson GOF uses categories and compares observed to expected frequencies.
test_GOF(
delayFit,
method = c("moran", "pearson", "nikulin", "NRR"),
estimated = TRUE,
verbose = 0
)An htest-object containing the GOF-test result
delay_model fit object
character(1). which method to use for GOF. Default is 'moran'.
flag. Moran test: was the parameter estimated?
integer. Verbosity level. The higher the more verbose debugging output.
Note that the GOF-tests are currently only implemented for models fitted with maximum product of spacings estimation (MPSE). These tests (Moran & Pearson) are still experimental. So, use with caution. Experimental code!