Learn R Programming

incubate (version 1.3.0)

transform.incubate_fit: Transform observed data to unit interval

Description

The transformation is the probability integral transform. It uses the cumulative distribution function with the estimated parameters of the model fit. All available data in the model fit is transformed.

Usage

# S3 method for incubate_fit
transform(`_data`, ...)

Value

The transformed data, either a vector (for single group) or a list with entries x and y (in two group scenario)

Arguments

_data

a fitted model object of class incubate_fit

...

currently ignored