The transformation is the probability integral transform. It uses the cumulative distribution function with the estimated parameters of the model fit. All available data in the model fit is transformed.
# S3 method for incubate_fit
transform(`_data`, ...)The transformed data, either a vector (for single group) or a list with entries x and y (in two group scenario)
a fitted model object of class incubate_fit
currently ignored