Learn R Programming

incubate (version 1.3.0)

update.incubate_fit: Refit an incubate_fit-object with specified optimization arguments. If more things need to be changed go back to delay_model and start from scratch.

Description

Refit an incubate_fit-object with specified optimization arguments. If more things need to be changed go back to delay_model and start from scratch.

Usage

# S3 method for incubate_fit
update(object, optim_args = NULL, verbose = 0, ...)

Value

The updated fitted object of class incubate_fit

Arguments

object

incubate_fit-object

optim_args

optimization arguments

verbose

integer flag. Requested verbosity during delay_fit

...

further arguments, currently not used.