incubate_fit-object with specified optimization arguments.
If more things need to be changed go back to delay_model and start from scratch.Refit an incubate_fit-object with specified optimization arguments.
If more things need to be changed go back to delay_model and start from scratch.
# S3 method for incubate_fit
update(object, optim_args = NULL, verbose = 0, ...)The updated fitted object of class incubate_fit
incubate_fit-object
optimization arguments
integer flag. Requested verbosity during delay_fit
further arguments, currently not used.