Generally, the weight W3 depends on the sample size and the shape parameter. The sample size of a group is fixed. Hence, we return a function that returns W3 for provided shape parameter as argument. If the sample size was used during the Monte-Carlo simulation study the coefficients of generalized logistic curve are returned directly. Otherwise the coefficients stem from a natural cubic spline fit based on the MCS.
w3FFint(nObs)W3-function for the given sample size. It is a function of shape.
sample size for which to build the W3-function
We run the cubic spline fit once when the package is loaded. This guarantees
that the spline function of the R-version of the current user is used and
hopefully with good performance. Function w3FFint is run repeatedly by the
objFunFactory(), once per group.